@@ -14,796 +14,795 @@ our @ISA = qw(Exporter);
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-# This allows declaration    use Graphics::Raylib::XS ':all';
+# This allows declaration	use Graphics::Raylib::XS ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
 our %EXPORT_TAGS = ( 'all' => [ qw(
-    BLEND_ADDITIVE
-    BLEND_ALPHA
-    BLEND_MULTIPLIED
-    CAMERA_CUSTOM
-    CAMERA_FIRST_PERSON
-    CAMERA_FREE
-    CAMERA_ORBITAL
-    CAMERA_THIRD_PERSON
-    COMPRESSED_ASTC_4x4_RGBA
-    COMPRESSED_ASTC_8x8_RGBA
-    COMPRESSED_DXT1_RGB
-    COMPRESSED_DXT1_RGBA
-    COMPRESSED_DXT3_RGBA
-    COMPRESSED_DXT5_RGBA
-    COMPRESSED_ETC1_RGB
-    COMPRESSED_ETC2_EAC_RGBA
-    COMPRESSED_ETC2_RGB
-    COMPRESSED_PVRT_RGB
-    COMPRESSED_PVRT_RGBA
-    DEG2RAD
-    FILTER_ANISOTROPIC_16X
-    FILTER_ANISOTROPIC_4X
-    FILTER_ANISOTROPIC_8X
-    FILTER_BILINEAR
-    FILTER_POINT
-    FILTER_TRILINEAR
-    FLAG_FULLSCREEN_MODE
-    FLAG_MSAA_4X_HINT
-    FLAG_SHOW_LOGO
-    FLAG_VSYNC_HINT
-    FLAG_WINDOW_DECORATED
-    FLAG_WINDOW_RESIZABLE
-    FLAG_WINDOW_TRANSPARENT
-    GAMEPAD_PLAYER1
-    GAMEPAD_PLAYER2
-    GAMEPAD_PLAYER3
-    GAMEPAD_PLAYER4
-    GAMEPAD_PS3_AXIS_L2
-    GAMEPAD_PS3_AXIS_LEFT_X
-    GAMEPAD_PS3_AXIS_LEFT_Y
-    GAMEPAD_PS3_AXIS_R2
-    GAMEPAD_PS3_AXIS_RIGHT_X
-    GAMEPAD_PS3_AXIS_RIGHT_Y
-    GAMEPAD_PS3_BUTTON_CIRCLE
-    GAMEPAD_PS3_BUTTON_CROSS
-    GAMEPAD_PS3_BUTTON_DOWN
-    GAMEPAD_PS3_BUTTON_L1
-    GAMEPAD_PS3_BUTTON_L2
-    GAMEPAD_PS3_BUTTON_LEFT
-    GAMEPAD_PS3_BUTTON_PS
-    GAMEPAD_PS3_BUTTON_R1
-    GAMEPAD_PS3_BUTTON_R2
-    GAMEPAD_PS3_BUTTON_RIGHT
-    GAMEPAD_PS3_BUTTON_SELECT
-    GAMEPAD_PS3_BUTTON_SQUARE
-    GAMEPAD_PS3_BUTTON_START
-    GAMEPAD_PS3_BUTTON_TRIANGLE
-    GAMEPAD_PS3_BUTTON_UP
-    GAMEPAD_XBOX_AXIS_LEFT_X
-    GAMEPAD_XBOX_AXIS_LEFT_Y
-    GAMEPAD_XBOX_AXIS_LT
-    GAMEPAD_XBOX_AXIS_RIGHT_X
-    GAMEPAD_XBOX_AXIS_RIGHT_Y
-    GAMEPAD_XBOX_AXIS_RT
-    GAMEPAD_XBOX_BUTTON_A
-    GAMEPAD_XBOX_BUTTON_B
-    GAMEPAD_XBOX_BUTTON_DOWN
-    GAMEPAD_XBOX_BUTTON_HOME
-    GAMEPAD_XBOX_BUTTON_LB
-    GAMEPAD_XBOX_BUTTON_LEFT
-    GAMEPAD_XBOX_BUTTON_RB
-    GAMEPAD_XBOX_BUTTON_RIGHT
-    GAMEPAD_XBOX_BUTTON_SELECT
-    GAMEPAD_XBOX_BUTTON_START
-    GAMEPAD_XBOX_BUTTON_UP
-    GAMEPAD_XBOX_BUTTON_X
-    GAMEPAD_XBOX_BUTTON_Y
-    GESTURE_DOUBLETAP
-    GESTURE_DRAG
-    GESTURE_HOLD
-    GESTURE_NONE
-    GESTURE_PINCH_IN
-    GESTURE_PINCH_OUT
-    GESTURE_SWIPE_DOWN
-    GESTURE_SWIPE_LEFT
-    GESTURE_SWIPE_RIGHT
-    GESTURE_SWIPE_UP
-    GESTURE_TAP
-    HMD_DEFAULT_DEVICE
-    HMD_OCULUS_GO
-    HMD_OCULUS_RIFT_CV1
-    HMD_OCULUS_RIFT_DK2
-    HMD_SONY_PSVR
-    HMD_VALVE_HTC_VIVE
-    KEY_A
-    KEY_B
-    KEY_BACK
-    KEY_BACKSPACE
-    KEY_C
-    KEY_D
-    KEY_DOWN
-    KEY_E
-    KEY_EIGHT
-    KEY_ENTER
-    KEY_ESCAPE
-    KEY_F
-    KEY_F1
-    KEY_F10
-    KEY_F11
-    KEY_F12
-    KEY_F2
-    KEY_F3
-    KEY_F4
-    KEY_F5
-    KEY_F6
-    KEY_F7
-    KEY_F8
-    KEY_F9
-    KEY_FIVE
-    KEY_FOUR
-    KEY_G
-    KEY_H
-    KEY_I
-    KEY_J
-    KEY_K
-    KEY_L
-    KEY_LEFT
-    KEY_LEFT_ALT
-    KEY_LEFT_CONTROL
-    KEY_LEFT_SHIFT
-    KEY_M
-    KEY_MENU
-    KEY_N
-    KEY_NINE
-    KEY_O
-    KEY_ONE
-    KEY_P
-    KEY_Q
-    KEY_R
-    KEY_RIGHT
-    KEY_RIGHT_ALT
-    KEY_RIGHT_CONTROL
-    KEY_RIGHT_SHIFT
-    KEY_S
-    KEY_SEVEN
-    KEY_SIX
-    KEY_SPACE
-    KEY_T
-    KEY_THREE
-    KEY_TWO
-    KEY_U
-    KEY_UP
-    KEY_V
-    KEY_VOLUME_DOWN
-    KEY_VOLUME_UP
-    KEY_W
-    KEY_X
-    KEY_Y
-    KEY_Z
-    KEY_ZERO
-    LOC_COLOR_AMBIENT
-    LOC_COLOR_DIFFUSE
-    LOC_COLOR_SPECULAR
-    LOC_MAP_ALBEDO
-    LOC_MAP_BRDF
-    LOC_MAP_CUBEMAP
-    LOC_MAP_DIFFUSE
-    LOC_MAP_EMISSION
-    LOC_MAP_HEIGHT
-    LOC_MAP_IRRADIANCE
-    LOC_MAP_METALNESS
-    LOC_MAP_NORMAL
-    LOC_MAP_OCCUSION
-    LOC_MAP_PREFILTER
-    LOC_MAP_ROUGHNESS
-    LOC_MAP_SPECULAR
-    LOC_MATRIX_MODEL
-    LOC_MATRIX_MVP
-    LOC_MATRIX_PROJECTION
-    LOC_MATRIX_VIEW
-    LOC_VECTOR_VIEW
-    LOC_VERTEX_COLOR
-    LOC_VERTEX_NORMAL
-    LOC_VERTEX_POSITION
-    LOC_VERTEX_TANGENT
-    LOC_VERTEX_TEXCOORD01
-    LOC_VERTEX_TEXCOORD02
-    LOG_DEBUG
-    LOG_ERROR
-    LOG_INFO
-    LOG_OTHER
-    LOG_WARNING
-    MAP_ALBEDO
-    MAP_BRDF
-    MAP_CUBEMAP
-    MAP_DIFFUSE
-    MAP_EMISSION
-    MAP_HEIGHT
-    MAP_IRRADIANCE
-    MAP_METALNESS
-    MAP_NORMAL
-    MAP_OCCLUSION
-    MAP_PREFILTER
-    MAP_ROUGHNESS
-    MAP_SPECULAR
-    MAX_MATERIAL_MAPS
-    MAX_SHADER_LOCATIONS
-    MAX_TOUCH_POINTS
-    MOUSE_LEFT_BUTTON
-    MOUSE_MIDDLE_BUTTON
-    MOUSE_RIGHT_BUTTON
-    RAD2DEG
-    RRES_TYPE_DIRECTORY
-    RRES_TYPE_FONT_CHARDATA
-    RRES_TYPE_FONT_IMAGE
-    RRES_TYPE_IMAGE
-    RRES_TYPE_RAW
-    RRES_TYPE_TEXT
-    RRES_TYPE_VERTEX
-    RRES_TYPE_WAVE
-    UNCOMPRESSED_GRAYSCALE
-    UNCOMPRESSED_GRAY_ALPHA
-    UNCOMPRESSED_R32G32B32
-    UNCOMPRESSED_R4G4B4A4
-    UNCOMPRESSED_R5G5B5A1
-    UNCOMPRESSED_R5G6B5
-    UNCOMPRESSED_R8G8B8
-    UNCOMPRESSED_R8G8B8A8
-    WRAP_CLAMP
-    WRAP_MIRROR
-    WRAP_REPEAT
-    false
-    true
-    Begin2dMode
-    Begin3dMode
-    BeginBlendMode
-    BeginDrawing
-    BeginShaderMode
-    BeginTextureMode
-    BeginVrDrawing
-    CalculateBoundingBox
-    ChangeDirectory
-    CheckCollisionBoxSphere
-    CheckCollisionBoxes
-    CheckCollisionCircleRec
-    CheckCollisionCircles
-    CheckCollisionPointCircle
-    CheckCollisionPointRec
-    CheckCollisionPointTriangle
-    CheckCollisionRayBox
-    CheckCollisionRaySphere
-    CheckCollisionRaySphereEx
-    CheckCollisionRecs
-    CheckCollisionSpheres
-    ClearBackground
-    ClearDroppedFiles
-    CloseAudioDevice
-    CloseAudioStream
-    CloseVrSimulator
-    CloseWindow
-    ColorToFloat
-    DisableCursor
-    DrawBillboard
-    DrawBillboardRec
-    DrawBoundingBox
-    DrawCircle
-    DrawCircle3D
-    DrawCircleGradient
-    DrawCircleLines
-    DrawCircleV
-    DrawCube
-    DrawCubeTexture
-    DrawCubeV
-    DrawCubeWires
-    DrawCylinder
-    DrawCylinderWires
-    DrawFPS
-    DrawGizmo
-    DrawGrid
-    DrawLine
-    DrawLine3D
-    DrawLineBezier
-    DrawLineEx
-    DrawLineV
-    DrawModel
-    DrawModelEx
-    DrawModelWires
-    DrawModelWiresEx
-    DrawPixel
-    DrawPixelV
-    DrawPlane
-    DrawPoly
-    DrawPolyEx
-    DrawPolyExLines
-    DrawRay
-    DrawRectangle
-    DrawRectangleGradientEx
-    DrawRectangleGradientH
-    DrawRectangleGradientV
-    DrawRectangleLines
-    DrawRectanglePro
-    DrawRectangleRec
-    DrawRectangleT
-    DrawRectangleV
-    DrawSphere
-    DrawSphereEx
-    DrawSphereWires
-    DrawText
-    DrawTextEx
-    DrawTexture
-    DrawTextureEx
-    DrawTexturePro
-    DrawTextureRec
-    DrawTextureV
-    DrawTriangle
-    DrawTriangleLines
-    EnableCursor
-    End2dMode
-    End3dMode
-    EndBlendMode
-    EndDrawing
-    EndShaderMode
-    EndTextureMode
-    EndVrDrawing
-    Fade
-    FormatText
-    GenImageCellular
-    GenImageChecked
-    GenImageColor
-    GenImageGradientH
-    GenImageGradientRadial
-    GenImageGradientV
-    GenImagePerlinNoise
-    GenImageWhiteNoise
-    GenMeshCube
-    GenMeshCubicmap
-    GenMeshCylinder
-    GenMeshHeightmap
-    GenMeshHemiSphere
-    GenMeshKnot
-    GenMeshPlane
-    GenMeshSphere
-    GenMeshTorus
-    GenTextureBRDF
-    GenTextureCubemap
-    GenTextureIrradiance
-    GenTextureMipmaps
-    GenTexturePrefilter
-    GetCameraMatrix
-    GetCollisionRayGround
-    GetCollisionRayMesh
-    GetCollisionRayTriangle
-    GetCollisionRec
-    GetColor
-    GetDefaultFont
-    GetDirectoryPath
-    GetExtension
-    GetFPS
-    GetFrameTime
-    GetGamepadAxisCount
-    GetGamepadAxisMovement
-    GetGamepadButtonPressed
-    GetGamepadName
-    GetGestureDetected
-    GetGestureDragAngle
-    GetGestureDragVector
-    GetGestureHoldDuration
-    GetGesturePinchAngle
-    GetGesturePinchVector
-    GetHexValue
-    GetImageData
-    GetKeyPressed
-    GetMousePosition
-    GetMouseRay
-    GetMouseWheelMove
-    GetMouseX
-    GetMouseY
-    GetMusicTimeLength
-    GetMusicTimePlayed
-    GetRandomValue
-    GetScreenHeight
-    GetScreenWidth
-    GetShaderDefault
-    GetShaderLocation
-    GetTextureData
-    GetTextureDefault
-    GetTouchPointsCount
-    GetTouchPosition
-    GetTouchX
-    GetTouchY
-    GetVrDeviceInfo
-    GetWaveData
-    GetWorkingDirectory
-    GetWorldToScreen
-    HideCursor
-    ImageAlphaMask
-    ImageColorBrightness
-    ImageColorContrast
-    ImageColorGrayscale
-    ImageColorInvert
-    ImageColorTint
-    ImageCopy
-    ImageCrop
-    ImageDither
-    ImageDraw
-    ImageDrawText
-    ImageDrawTextEx
-    ImageFlipHorizontal
-    ImageFlipVertical
-    ImageFormat
-    ImageResize
-    ImageResizeNN
-    ImageText
-    ImageTextEx
-    ImageToPOT
-    InitAudioDevice
-    InitAudioStream
-    InitVrSimulator
-    InitWindow
-    IsAudioBufferProcessed
-    IsAudioDeviceReady
-    IsCursorHidden
-    IsFileDropped
-    IsFileExtension
-    IsGamepadAvailable
-    IsGamepadButtonDown
-    IsGamepadButtonPressed
-    IsGamepadButtonReleased
-    IsGamepadButtonUp
-    IsGamepadName
-    IsGestureDetected
-    IsKeyDown
-    IsKeyPressed
-    IsKeyReleased
-    IsKeyUp
-    IsMouseButtonDown
-    IsMouseButtonPressed
-    IsMouseButtonReleased
-    IsMouseButtonUp
-    IsMusicPlaying
-    IsSoundPlaying
-    IsVrSimulatorReady
-    IsWindowMinimized
-    LoadImage
-    LoadImageEx
-    LoadImagePro
-    LoadImageRaw
-    LoadImageFromAV
-    LoadImageFromAV_uninitialized_mem
-    LoadImageFromAV_transposed
-    LoadImageFromAV_transposed_uninitialized_mem
-    LoadMaterial
-    LoadMaterialDefault
-    LoadMesh
-    LoadModel
-    LoadModelFromMesh
-    LoadMusicStream
-    LoadRenderTexture
-    LoadShader
-    LoadSound
-    LoadSoundFromWave
-    LoadSpriteFont
-    LoadSpriteFontEx
-    LoadText
-    LoadTexture
-    LoadTextureFromImage
-    LoadWave
-    LoadWaveEx
-    MatrixIdentity
-    MatrixToFloat
-    MeasureText
-    MeasureTextEx
-    PauseAudioStream
-    PauseMusicStream
-    PauseSound
-    PlayAudioStream
-    PlayMusicStream
-    PlaySound
-    ResumeAudioStream
-    ResumeMusicStream
-    ResumeSound
-    SaveImageAs
-    SetCameraAltControl
-    SetCameraMode
-    SetCameraMoveControls
-    SetCameraPanControl
-    SetCameraSmoothZoomControl
-    SetConfigFlags
-    SetExitKey
-    SetGesturesEnabled
-    SetMasterVolume
-    SetMatrixModelview
-    SetMatrixProjection
-    SetMousePosition
-    SetMusicLoopCount
-    SetMusicPitch
-    SetMusicVolume
-    SetShaderValue
-    SetShaderValueMatrix
-    SetShaderValuei
-    SetSoundPitch
-    SetSoundVolume
-    SetTargetFPS
-    SetTextureFilter
-    SetTextureWrap
-    SetVrDistortionShader
-    SetWindowIcon
-    SetWindowMinSize
-    SetWindowMonitor
-    SetWindowPosition
-    SetWindowTitle
-    ShowCursor
-    ShowLogo
-    StopAudioStream
-    StopMusicStream
-    StopSound
-    StorageLoadValue
-    StorageSaveValue
-    SubText
-    TakeScreenshot
-    ToggleFullscreen
-    ToggleVrMode
-    TraceLog
-    UnloadImage
-    UnloadMaterial
-    UnloadMesh
-    UnloadModel
-    UnloadMusicStream
-    UnloadRenderTexture
-    UnloadShader
-    UnloadSound
-    UnloadSpriteFont
-    UnloadTexture
-    UnloadWave
-    UpdateAudioStream
-    UpdateCamera
-    UpdateMusicStream
-    UpdateSound
-    UpdateTexture
-    UpdateTextureFromImage
-    UpdateVrTracking
-    Vector3One
-    Vector3ToFloat
-    Vector3Zero
-    WaveCopy
-    WaveCrop
-    WaveFormat
-    WindowShouldClose
+	BLEND_ADDITIVE
+	BLEND_ALPHA
+	BLEND_MULTIPLIED
+	CAMERA_CUSTOM
+	CAMERA_FIRST_PERSON
+	CAMERA_FREE
+	CAMERA_ORBITAL
+	CAMERA_THIRD_PERSON
+	COMPRESSED_ASTC_4x4_RGBA
+	COMPRESSED_ASTC_8x8_RGBA
+	COMPRESSED_DXT1_RGB
+	COMPRESSED_DXT1_RGBA
+	COMPRESSED_DXT3_RGBA
+	COMPRESSED_DXT5_RGBA
+	COMPRESSED_ETC1_RGB
+	COMPRESSED_ETC2_EAC_RGBA
+	COMPRESSED_ETC2_RGB
+	COMPRESSED_PVRT_RGB
+	COMPRESSED_PVRT_RGBA
+	DEG2RAD
+	FILTER_ANISOTROPIC_16X
+	FILTER_ANISOTROPIC_4X
+	FILTER_ANISOTROPIC_8X
+	FILTER_BILINEAR
+	FILTER_POINT
+	FILTER_TRILINEAR
+	FLAG_FULLSCREEN_MODE
+	FLAG_MSAA_4X_HINT
+	FLAG_SHOW_LOGO
+	FLAG_VSYNC_HINT
+	FLAG_WINDOW_DECORATED
+	FLAG_WINDOW_RESIZABLE
+	FLAG_WINDOW_TRANSPARENT
+	GAMEPAD_PLAYER1
+	GAMEPAD_PLAYER2
+	GAMEPAD_PLAYER3
+	GAMEPAD_PLAYER4
+	GAMEPAD_PS3_AXIS_L2
+	GAMEPAD_PS3_AXIS_LEFT_X
+	GAMEPAD_PS3_AXIS_LEFT_Y
+	GAMEPAD_PS3_AXIS_R2
+	GAMEPAD_PS3_AXIS_RIGHT_X
+	GAMEPAD_PS3_AXIS_RIGHT_Y
+	GAMEPAD_PS3_BUTTON_CIRCLE
+	GAMEPAD_PS3_BUTTON_CROSS
+	GAMEPAD_PS3_BUTTON_DOWN
+	GAMEPAD_PS3_BUTTON_L1
+	GAMEPAD_PS3_BUTTON_L2
+	GAMEPAD_PS3_BUTTON_LEFT
+	GAMEPAD_PS3_BUTTON_PS
+	GAMEPAD_PS3_BUTTON_R1
+	GAMEPAD_PS3_BUTTON_R2
+	GAMEPAD_PS3_BUTTON_RIGHT
+	GAMEPAD_PS3_BUTTON_SELECT
+	GAMEPAD_PS3_BUTTON_SQUARE
+	GAMEPAD_PS3_BUTTON_START
+	GAMEPAD_PS3_BUTTON_TRIANGLE
+	GAMEPAD_PS3_BUTTON_UP
+	GAMEPAD_XBOX_AXIS_LEFT_X
+	GAMEPAD_XBOX_AXIS_LEFT_Y
+	GAMEPAD_XBOX_AXIS_LT
+	GAMEPAD_XBOX_AXIS_RIGHT_X
+	GAMEPAD_XBOX_AXIS_RIGHT_Y
+	GAMEPAD_XBOX_AXIS_RT
+	GAMEPAD_XBOX_BUTTON_A
+	GAMEPAD_XBOX_BUTTON_B
+	GAMEPAD_XBOX_BUTTON_DOWN
+	GAMEPAD_XBOX_BUTTON_HOME
+	GAMEPAD_XBOX_BUTTON_LB
+	GAMEPAD_XBOX_BUTTON_LEFT
+	GAMEPAD_XBOX_BUTTON_RB
+	GAMEPAD_XBOX_BUTTON_RIGHT
+	GAMEPAD_XBOX_BUTTON_SELECT
+	GAMEPAD_XBOX_BUTTON_START
+	GAMEPAD_XBOX_BUTTON_UP
+	GAMEPAD_XBOX_BUTTON_X
+	GAMEPAD_XBOX_BUTTON_Y
+	GESTURE_DOUBLETAP
+	GESTURE_DRAG
+	GESTURE_HOLD
+	GESTURE_NONE
+	GESTURE_PINCH_IN
+	GESTURE_PINCH_OUT
+	GESTURE_SWIPE_DOWN
+	GESTURE_SWIPE_LEFT
+	GESTURE_SWIPE_RIGHT
+	GESTURE_SWIPE_UP
+	GESTURE_TAP
+	HMD_DEFAULT_DEVICE
+	HMD_OCULUS_GO
+	HMD_OCULUS_RIFT_CV1
+	HMD_OCULUS_RIFT_DK2
+	HMD_SONY_PSVR
+	HMD_VALVE_HTC_VIVE
+	KEY_A
+	KEY_B
+	KEY_BACK
+	KEY_BACKSPACE
+	KEY_C
+	KEY_D
+	KEY_DOWN
+	KEY_E
+	KEY_EIGHT
+	KEY_ENTER
+	KEY_ESCAPE
+	KEY_F
+	KEY_F1
+	KEY_F10
+	KEY_F11
+	KEY_F12
+	KEY_F2
+	KEY_F3
+	KEY_F4
+	KEY_F5
+	KEY_F6
+	KEY_F7
+	KEY_F8
+	KEY_F9
+	KEY_FIVE
+	KEY_FOUR
+	KEY_G
+	KEY_H
+	KEY_I
+	KEY_J
+	KEY_K
+	KEY_L
+	KEY_LEFT
+	KEY_LEFT_ALT
+	KEY_LEFT_CONTROL
+	KEY_LEFT_SHIFT
+	KEY_M
+	KEY_MENU
+	KEY_N
+	KEY_NINE
+	KEY_O
+	KEY_ONE
+	KEY_P
+	KEY_Q
+	KEY_R
+	KEY_RIGHT
+	KEY_RIGHT_ALT
+	KEY_RIGHT_CONTROL
+	KEY_RIGHT_SHIFT
+	KEY_S
+	KEY_SEVEN
+	KEY_SIX
+	KEY_SPACE
+	KEY_T
+	KEY_THREE
+	KEY_TWO
+	KEY_U
+	KEY_UP
+	KEY_V
+	KEY_VOLUME_DOWN
+	KEY_VOLUME_UP
+	KEY_W
+	KEY_X
+	KEY_Y
+	KEY_Z
+	KEY_ZERO
+	LOC_COLOR_AMBIENT
+	LOC_COLOR_DIFFUSE
+	LOC_COLOR_SPECULAR
+	LOC_MAP_ALBEDO
+	LOC_MAP_BRDF
+	LOC_MAP_CUBEMAP
+	LOC_MAP_DIFFUSE
+	LOC_MAP_EMISSION
+	LOC_MAP_HEIGHT
+	LOC_MAP_IRRADIANCE
+	LOC_MAP_METALNESS
+	LOC_MAP_NORMAL
+	LOC_MAP_OCCUSION
+	LOC_MAP_PREFILTER
+	LOC_MAP_ROUGHNESS
+	LOC_MAP_SPECULAR
+	LOC_MATRIX_MODEL
+	LOC_MATRIX_MVP
+	LOC_MATRIX_PROJECTION
+	LOC_MATRIX_VIEW
+	LOC_VECTOR_VIEW
+	LOC_VERTEX_COLOR
+	LOC_VERTEX_NORMAL
+	LOC_VERTEX_POSITION
+	LOC_VERTEX_TANGENT
+	LOC_VERTEX_TEXCOORD01
+	LOC_VERTEX_TEXCOORD02
+	LOG_DEBUG
+	LOG_ERROR
+	LOG_INFO
+	LOG_OTHER
+	LOG_WARNING
+	MAP_ALBEDO
+	MAP_BRDF
+	MAP_CUBEMAP
+	MAP_DIFFUSE
+	MAP_EMISSION
+	MAP_HEIGHT
+	MAP_IRRADIANCE
+	MAP_METALNESS
+	MAP_NORMAL
+	MAP_OCCLUSION
+	MAP_PREFILTER
+	MAP_ROUGHNESS
+	MAP_SPECULAR
+	MAX_MATERIAL_MAPS
+	MAX_SHADER_LOCATIONS
+	MAX_TOUCH_POINTS
+	MOUSE_LEFT_BUTTON
+	MOUSE_MIDDLE_BUTTON
+	MOUSE_RIGHT_BUTTON
+	RAD2DEG
+	UNCOMPRESSED_GRAYSCALE
+	UNCOMPRESSED_GRAY_ALPHA
+	UNCOMPRESSED_R32
+	UNCOMPRESSED_R32G32B32
+	UNCOMPRESSED_R32G32B32A32
+	UNCOMPRESSED_R4G4B4A4
+	UNCOMPRESSED_R5G5B5A1
+	UNCOMPRESSED_R5G6B5
+	UNCOMPRESSED_R8G8B8
+	UNCOMPRESSED_R8G8B8A8
+	WRAP_CLAMP
+	WRAP_MIRROR
+	WRAP_REPEAT
+	false
+	true
+	Begin2dMode
+	Begin3dMode
+	BeginBlendMode
+	BeginDrawing
+	BeginShaderMode
+	BeginTextureMode
+	BeginVrDrawing
+	CalculateBoundingBox
+	ChangeDirectory
+	CheckCollisionBoxSphere
+	CheckCollisionBoxes
+	CheckCollisionCircleRec
+	CheckCollisionCircles
+	CheckCollisionPointCircle
+	CheckCollisionPointRec
+	CheckCollisionPointTriangle
+	CheckCollisionRayBox
+	CheckCollisionRaySphere
+	CheckCollisionRaySphereEx
+	CheckCollisionRecs
+	CheckCollisionSpheres
+	ClearBackground
+	ClearDroppedFiles
+	CloseAudioDevice
+	CloseAudioStream
+	CloseVrSimulator
+	CloseWindow
+	ColorToFloat
+	DisableCursor
+	DrawBillboard
+	DrawBillboardRec
+	DrawBoundingBox
+	DrawCircle
+	DrawCircle3D
+	DrawCircleGradient
+	DrawCircleLines
+	DrawCircleV
+	DrawCube
+	DrawCubeTexture
+	DrawCubeV
+	DrawCubeWires
+	DrawCylinder
+	DrawCylinderWires
+	DrawFPS
+	DrawGizmo
+	DrawGrid
+	DrawLine
+	DrawLine3D
+	DrawLineBezier
+	DrawLineEx
+	DrawLineV
+	DrawModel
+	DrawModelEx
+	DrawModelWires
+	DrawModelWiresEx
+	DrawPixel
+	DrawPixelV
+	DrawPlane
+	DrawPoly
+	DrawPolyEx
+	DrawPolyExLines
+	DrawRay
+	DrawRectangle
+	DrawRectangleGradientEx
+	DrawRectangleGradientH
+	DrawRectangleGradientV
+	DrawRectangleLines
+	DrawRectanglePro
+	DrawRectangleRec
+	DrawRectangleV
+	DrawSphere
+	DrawSphereEx
+	DrawSphereWires
+	DrawText
+	DrawTextEx
+	DrawTexture
+	DrawTextureEx
+	DrawTexturePro
+	DrawTextureRec
+	DrawTextureV
+	DrawTriangle
+	DrawTriangleLines
+	EnableCursor
+	End2dMode
+	End3dMode
+	EndBlendMode
+	EndDrawing
+	EndShaderMode
+	EndTextureMode
+	EndVrDrawing
+	Fade
+	FormatText
+	GenImageCellular
+	GenImageChecked
+	GenImageColor
+	GenImageGradientH
+	GenImageGradientRadial
+	GenImageGradientV
+	GenImagePerlinNoise
+	GenImageWhiteNoise
+	GenMeshCube
+	GenMeshCubicmap
+	GenMeshCylinder
+	GenMeshHeightmap
+	GenMeshHemiSphere
+	GenMeshKnot
+	GenMeshPlane
+	GenMeshSphere
+	GenMeshTorus
+	GenTextureBRDF
+	GenTextureCubemap
+	GenTextureIrradiance
+	GenTextureMipmaps
+	GenTexturePrefilter
+	GetCameraMatrix
+	GetCollisionRayGround
+	GetCollisionRayMesh
+	GetCollisionRayTriangle
+	GetCollisionRec
+	GetColor
+	GetDefaultFont
+	GetDirectoryPath
+	GetExtension
+	GetFPS
+	GetFileName
+	GetFrameTime
+	GetGamepadAxisCount
+	GetGamepadAxisMovement
+	GetGamepadButtonPressed
+	GetGamepadName
+	GetGestureDetected
+	GetGestureDragAngle
+	GetGestureDragVector
+	GetGestureHoldDuration
+	GetGesturePinchAngle
+	GetGesturePinchVector
+	GetHexValue
+	GetImageData
+	GetKeyPressed
+	GetMatrixModelview
+	GetMousePosition
+	GetMouseRay
+	GetMouseWheelMove
+	GetMouseX
+	GetMouseY
+	GetMusicTimeLength
+	GetMusicTimePlayed
+	GetPixelDataSize
+	GetRandomValue
+	GetScreenHeight
+	GetScreenWidth
+	GetShaderDefault
+	GetShaderLocation
+	GetTextureData
+	GetTextureDefault
+	GetTime
+	GetTouchPointsCount
+	GetTouchPosition
+	GetTouchX
+	GetTouchY
+	GetVrDeviceInfo
+	GetWaveData
+	GetWorkingDirectory
+	GetWorldToScreen
+	HideCursor
+	ImageAlphaClear
+	ImageAlphaCrop
+	ImageAlphaMask
+	ImageAlphaPremultiply
+	ImageColorBrightness
+	ImageColorContrast
+	ImageColorGrayscale
+	ImageColorInvert
+	ImageColorTint
+	ImageCopy
+	ImageCrop
+	ImageDither
+	ImageDraw
+	ImageDrawText
+	ImageDrawTextEx
+	ImageFlipHorizontal
+	ImageFlipVertical
+	ImageFormat
+	ImageMipmaps
+	ImageResize
+	ImageResizeNN
+	ImageText
+	ImageTextEx
+	ImageToPOT
+	InitAudioDevice
+	InitAudioStream
+	InitVrSimulator
+	InitWindow
+	IsAudioBufferProcessed
+	IsAudioDeviceReady
+	IsAudioStreamPlaying
+	IsCursorHidden
+	IsFileDropped
+	IsFileExtension
+	IsGamepadAvailable
+	IsGamepadButtonDown
+	IsGamepadButtonPressed
+	IsGamepadButtonReleased
+	IsGamepadButtonUp
+	IsGamepadName
+	IsGestureDetected
+	IsKeyDown
+	IsKeyPressed
+	IsKeyReleased
+	IsKeyUp
+	IsMouseButtonDown
+	IsMouseButtonPressed
+	IsMouseButtonReleased
+	IsMouseButtonUp
+	IsMusicPlaying
+	IsSoundPlaying
+	IsVrSimulatorReady
+	IsWindowMinimized
+	LoadImage
+	LoadImageEx
+	LoadImagePro
+	LoadImageRaw
+	LoadImageFromAV
+	LoadImageFromAV_uninitialized_mem
+	LoadImageFromAV_transposed
+	LoadImageFromAV_transposed_uninitialized_mem
+	LoadMaterial
+	LoadMaterialDefault
+	LoadMesh
+	LoadModel
+	LoadModelFromMesh
+	LoadMusicStream
+	LoadRenderTexture
+	LoadShader
+	LoadSound
+	LoadSoundFromWave
+	LoadSpriteFont
+	LoadSpriteFontEx
+	LoadText
+	LoadTexture
+	LoadTextureFromImage
+	LoadWave
+	LoadWaveEx
+	MatrixIdentity
+	MatrixToFloat
+	MeasureText
+	MeasureTextEx
+	PauseAudioStream
+	PauseMusicStream
+	PauseSound
+	PlayAudioStream
+	PlayMusicStream
+	PlaySound
+	ResumeAudioStream
+	ResumeMusicStream
+	ResumeSound
+	SaveImageAs
+	SetAudioStreamPitch
+	SetAudioStreamVolume
+	SetCameraAltControl
+	SetCameraMode
+	SetCameraMoveControls
+	SetCameraPanControl
+	SetCameraSmoothZoomControl
+	SetConfigFlags
+	SetExitKey
+	SetGesturesEnabled
+	SetMasterVolume
+	SetMatrixModelview
+	SetMatrixProjection
+	SetMousePosition
+	SetMusicLoopCount
+	SetMusicPitch
+	SetMusicVolume
+	SetShaderValue
+	SetShaderValueMatrix
+	SetShaderValuei
+	SetSoundPitch
+	SetSoundVolume
+	SetTargetFPS
+	SetTextureFilter
+	SetTextureWrap
+	SetTraceLog
+	SetVrDistortionShader
+	SetWindowIcon
+	SetWindowMinSize
+	SetWindowMonitor
+	SetWindowPosition
+	SetWindowTitle
+	ShowCursor
+	ShowLogo
+	StopAudioStream
+	StopMusicStream
+	StopSound
+	StorageLoadValue
+	StorageSaveValue
+	SubText
+	TakeScreenshot
+	ToggleFullscreen
+	ToggleVrMode
+	TraceLog
+	UnloadImage
+	UnloadMaterial
+	UnloadMesh
+	UnloadModel
+	UnloadMusicStream
+	UnloadRenderTexture
+	UnloadShader
+	UnloadSound
+	UnloadSpriteFont
+	UnloadTexture
+	UnloadWave
+	UpdateAudioStream
+	UpdateCamera
+	UpdateMusicStream
+	UpdateSound
+	UpdateTexture
+	UpdateTextureFromImage
+	UpdateVrTracking
+	Vector3One
+	Vector3ToFloat
+	Vector3Zero
+	WaveCopy
+	WaveCrop
+	WaveFormat
+	WindowShouldClose
 ) ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw(
-    BLEND_ADDITIVE
-    BLEND_ALPHA
-    BLEND_MULTIPLIED
-    CAMERA_CUSTOM
-    CAMERA_FIRST_PERSON
-    CAMERA_FREE
-    CAMERA_ORBITAL
-    CAMERA_THIRD_PERSON
-    COMPRESSED_ASTC_4x4_RGBA
-    COMPRESSED_ASTC_8x8_RGBA
-    COMPRESSED_DXT1_RGB
-    COMPRESSED_DXT1_RGBA
-    COMPRESSED_DXT3_RGBA
-    COMPRESSED_DXT5_RGBA
-    COMPRESSED_ETC1_RGB
-    COMPRESSED_ETC2_EAC_RGBA
-    COMPRESSED_ETC2_RGB
-    COMPRESSED_PVRT_RGB
-    COMPRESSED_PVRT_RGBA
-    DEG2RAD
-    FILTER_ANISOTROPIC_16X
-    FILTER_ANISOTROPIC_4X
-    FILTER_ANISOTROPIC_8X
-    FILTER_BILINEAR
-    FILTER_POINT
-    FILTER_TRILINEAR
-    FLAG_FULLSCREEN_MODE
-    FLAG_MSAA_4X_HINT
-    FLAG_SHOW_LOGO
-    FLAG_VSYNC_HINT
-    FLAG_WINDOW_DECORATED
-    FLAG_WINDOW_RESIZABLE
-    FLAG_WINDOW_TRANSPARENT
-    GAMEPAD_PLAYER1
-    GAMEPAD_PLAYER2
-    GAMEPAD_PLAYER3
-    GAMEPAD_PLAYER4
-    GAMEPAD_PS3_AXIS_L2
-    GAMEPAD_PS3_AXIS_LEFT_X
-    GAMEPAD_PS3_AXIS_LEFT_Y
-    GAMEPAD_PS3_AXIS_R2
-    GAMEPAD_PS3_AXIS_RIGHT_X
-    GAMEPAD_PS3_AXIS_RIGHT_Y
-    GAMEPAD_PS3_BUTTON_CIRCLE
-    GAMEPAD_PS3_BUTTON_CROSS
-    GAMEPAD_PS3_BUTTON_DOWN
-    GAMEPAD_PS3_BUTTON_L1
-    GAMEPAD_PS3_BUTTON_L2
-    GAMEPAD_PS3_BUTTON_LEFT
-    GAMEPAD_PS3_BUTTON_PS
-    GAMEPAD_PS3_BUTTON_R1
-    GAMEPAD_PS3_BUTTON_R2
-    GAMEPAD_PS3_BUTTON_RIGHT
-    GAMEPAD_PS3_BUTTON_SELECT
-    GAMEPAD_PS3_BUTTON_SQUARE
-    GAMEPAD_PS3_BUTTON_START
-    GAMEPAD_PS3_BUTTON_TRIANGLE
-    GAMEPAD_PS3_BUTTON_UP
-    GAMEPAD_XBOX_AXIS_LEFT_X
-    GAMEPAD_XBOX_AXIS_LEFT_Y
-    GAMEPAD_XBOX_AXIS_LT
-    GAMEPAD_XBOX_AXIS_RIGHT_X
-    GAMEPAD_XBOX_AXIS_RIGHT_Y
-    GAMEPAD_XBOX_AXIS_RT
-    GAMEPAD_XBOX_BUTTON_A
-    GAMEPAD_XBOX_BUTTON_B
-    GAMEPAD_XBOX_BUTTON_DOWN
-    GAMEPAD_XBOX_BUTTON_HOME
-    GAMEPAD_XBOX_BUTTON_LB
-    GAMEPAD_XBOX_BUTTON_LEFT
-    GAMEPAD_XBOX_BUTTON_RB
-    GAMEPAD_XBOX_BUTTON_RIGHT
-    GAMEPAD_XBOX_BUTTON_SELECT
-    GAMEPAD_XBOX_BUTTON_START
-    GAMEPAD_XBOX_BUTTON_UP
-    GAMEPAD_XBOX_BUTTON_X
-    GAMEPAD_XBOX_BUTTON_Y
-    GESTURE_DOUBLETAP
-    GESTURE_DRAG
-    GESTURE_HOLD
-    GESTURE_NONE
-    GESTURE_PINCH_IN
-    GESTURE_PINCH_OUT
-    GESTURE_SWIPE_DOWN
-    GESTURE_SWIPE_LEFT
-    GESTURE_SWIPE_RIGHT
-    GESTURE_SWIPE_UP
-    GESTURE_TAP
-    HMD_DEFAULT_DEVICE
-    HMD_OCULUS_GO
-    HMD_OCULUS_RIFT_CV1
-    HMD_OCULUS_RIFT_DK2
-    HMD_SONY_PSVR
-    HMD_VALVE_HTC_VIVE
-    KEY_A
-    KEY_B
-    KEY_BACK
-    KEY_BACKSPACE
-    KEY_C
-    KEY_D
-    KEY_DOWN
-    KEY_E
-    KEY_EIGHT
-    KEY_ENTER
-    KEY_ESCAPE
-    KEY_F
-    KEY_F1
-    KEY_F10
-    KEY_F11
-    KEY_F12
-    KEY_F2
-    KEY_F3
-    KEY_F4
-    KEY_F5
-    KEY_F6
-    KEY_F7
-    KEY_F8
-    KEY_F9
-    KEY_FIVE
-    KEY_FOUR
-    KEY_G
-    KEY_H
-    KEY_I
-    KEY_J
-    KEY_K
-    KEY_L
-    KEY_LEFT
-    KEY_LEFT_ALT
-    KEY_LEFT_CONTROL
-    KEY_LEFT_SHIFT
-    KEY_M
-    KEY_MENU
-    KEY_N
-    KEY_NINE
-    KEY_O
-    KEY_ONE
-    KEY_P
-    KEY_Q
-    KEY_R
-    KEY_RIGHT
-    KEY_RIGHT_ALT
-    KEY_RIGHT_CONTROL
-    KEY_RIGHT_SHIFT
-    KEY_S
-    KEY_SEVEN
-    KEY_SIX
-    KEY_SPACE
-    KEY_T
-    KEY_THREE
-    KEY_TWO
-    KEY_U
-    KEY_UP
-    KEY_V
-    KEY_VOLUME_DOWN
-    KEY_VOLUME_UP
-    KEY_W
-    KEY_X
-    KEY_Y
-    KEY_Z
-    KEY_ZERO
-    LOC_COLOR_AMBIENT
-    LOC_COLOR_DIFFUSE
-    LOC_COLOR_SPECULAR
-    LOC_MAP_ALBEDO
-    LOC_MAP_BRDF
-    LOC_MAP_CUBEMAP
-    LOC_MAP_DIFFUSE
-    LOC_MAP_EMISSION
-    LOC_MAP_HEIGHT
-    LOC_MAP_IRRADIANCE
-    LOC_MAP_METALNESS
-    LOC_MAP_NORMAL
-    LOC_MAP_OCCUSION
-    LOC_MAP_PREFILTER
-    LOC_MAP_ROUGHNESS
-    LOC_MAP_SPECULAR
-    LOC_MATRIX_MODEL
-    LOC_MATRIX_MVP
-    LOC_MATRIX_PROJECTION
-    LOC_MATRIX_VIEW
-    LOC_VECTOR_VIEW
-    LOC_VERTEX_COLOR
-    LOC_VERTEX_NORMAL
-    LOC_VERTEX_POSITION
-    LOC_VERTEX_TANGENT
-    LOC_VERTEX_TEXCOORD01
-    LOC_VERTEX_TEXCOORD02
-    LOG_DEBUG
-    LOG_ERROR
-    LOG_INFO
-    LOG_OTHER
-    LOG_WARNING
-    MAP_ALBEDO
-    MAP_BRDF
-    MAP_CUBEMAP
-    MAP_DIFFUSE
-    MAP_EMISSION
-    MAP_HEIGHT
-    MAP_IRRADIANCE
-    MAP_METALNESS
-    MAP_NORMAL
-    MAP_OCCLUSION
-    MAP_PREFILTER
-    MAP_ROUGHNESS
-    MAP_SPECULAR
-    MAX_MATERIAL_MAPS
-    MAX_SHADER_LOCATIONS
-    MAX_TOUCH_POINTS
-    MOUSE_LEFT_BUTTON
-    MOUSE_MIDDLE_BUTTON
-    MOUSE_RIGHT_BUTTON
-    RAD2DEG
-    RRES_TYPE_DIRECTORY
-    RRES_TYPE_FONT_CHARDATA
-    RRES_TYPE_FONT_IMAGE
-    RRES_TYPE_IMAGE
-    RRES_TYPE_RAW
-    RRES_TYPE_TEXT
-    RRES_TYPE_VERTEX
-    RRES_TYPE_WAVE
-    UNCOMPRESSED_GRAYSCALE
-    UNCOMPRESSED_GRAY_ALPHA
-    UNCOMPRESSED_R32G32B32
-    UNCOMPRESSED_R4G4B4A4
-    UNCOMPRESSED_R5G5B5A1
-    UNCOMPRESSED_R5G6B5
-    UNCOMPRESSED_R8G8B8
-    UNCOMPRESSED_R8G8B8A8
-    WRAP_CLAMP
-    WRAP_MIRROR
-    WRAP_REPEAT
-    false
-    true
+	BLEND_ADDITIVE
+	BLEND_ALPHA
+	BLEND_MULTIPLIED
+	CAMERA_CUSTOM
+	CAMERA_FIRST_PERSON
+	CAMERA_FREE
+	CAMERA_ORBITAL
+	CAMERA_THIRD_PERSON
+	COMPRESSED_ASTC_4x4_RGBA
+	COMPRESSED_ASTC_8x8_RGBA
+	COMPRESSED_DXT1_RGB
+	COMPRESSED_DXT1_RGBA
+	COMPRESSED_DXT3_RGBA
+	COMPRESSED_DXT5_RGBA
+	COMPRESSED_ETC1_RGB
+	COMPRESSED_ETC2_EAC_RGBA
+	COMPRESSED_ETC2_RGB
+	COMPRESSED_PVRT_RGB
+	COMPRESSED_PVRT_RGBA
+	DEG2RAD
+	FILTER_ANISOTROPIC_16X
+	FILTER_ANISOTROPIC_4X
+	FILTER_ANISOTROPIC_8X
+	FILTER_BILINEAR
+	FILTER_POINT
+	FILTER_TRILINEAR
+	FLAG_FULLSCREEN_MODE
+	FLAG_MSAA_4X_HINT
+	FLAG_SHOW_LOGO
+	FLAG_VSYNC_HINT
+	FLAG_WINDOW_DECORATED
+	FLAG_WINDOW_RESIZABLE
+	FLAG_WINDOW_TRANSPARENT
+	GAMEPAD_PLAYER1
+	GAMEPAD_PLAYER2
+	GAMEPAD_PLAYER3
+	GAMEPAD_PLAYER4
+	GAMEPAD_PS3_AXIS_L2
+	GAMEPAD_PS3_AXIS_LEFT_X
+	GAMEPAD_PS3_AXIS_LEFT_Y
+	GAMEPAD_PS3_AXIS_R2
+	GAMEPAD_PS3_AXIS_RIGHT_X
+	GAMEPAD_PS3_AXIS_RIGHT_Y
+	GAMEPAD_PS3_BUTTON_CIRCLE
+	GAMEPAD_PS3_BUTTON_CROSS
+	GAMEPAD_PS3_BUTTON_DOWN
+	GAMEPAD_PS3_BUTTON_L1
+	GAMEPAD_PS3_BUTTON_L2
+	GAMEPAD_PS3_BUTTON_LEFT
+	GAMEPAD_PS3_BUTTON_PS
+	GAMEPAD_PS3_BUTTON_R1
+	GAMEPAD_PS3_BUTTON_R2
+	GAMEPAD_PS3_BUTTON_RIGHT
+	GAMEPAD_PS3_BUTTON_SELECT
+	GAMEPAD_PS3_BUTTON_SQUARE
+	GAMEPAD_PS3_BUTTON_START
+	GAMEPAD_PS3_BUTTON_TRIANGLE
+	GAMEPAD_PS3_BUTTON_UP
+	GAMEPAD_XBOX_AXIS_LEFT_X
+	GAMEPAD_XBOX_AXIS_LEFT_Y
+	GAMEPAD_XBOX_AXIS_LT
+	GAMEPAD_XBOX_AXIS_RIGHT_X
+	GAMEPAD_XBOX_AXIS_RIGHT_Y
+	GAMEPAD_XBOX_AXIS_RT
+	GAMEPAD_XBOX_BUTTON_A
+	GAMEPAD_XBOX_BUTTON_B
+	GAMEPAD_XBOX_BUTTON_DOWN
+	GAMEPAD_XBOX_BUTTON_HOME
+	GAMEPAD_XBOX_BUTTON_LB
+	GAMEPAD_XBOX_BUTTON_LEFT
+	GAMEPAD_XBOX_BUTTON_RB
+	GAMEPAD_XBOX_BUTTON_RIGHT
+	GAMEPAD_XBOX_BUTTON_SELECT
+	GAMEPAD_XBOX_BUTTON_START
+	GAMEPAD_XBOX_BUTTON_UP
+	GAMEPAD_XBOX_BUTTON_X
+	GAMEPAD_XBOX_BUTTON_Y
+	GESTURE_DOUBLETAP
+	GESTURE_DRAG
+	GESTURE_HOLD
+	GESTURE_NONE
+	GESTURE_PINCH_IN
+	GESTURE_PINCH_OUT
+	GESTURE_SWIPE_DOWN
+	GESTURE_SWIPE_LEFT
+	GESTURE_SWIPE_RIGHT
+	GESTURE_SWIPE_UP
+	GESTURE_TAP
+	HMD_DEFAULT_DEVICE
+	HMD_OCULUS_GO
+	HMD_OCULUS_RIFT_CV1
+	HMD_OCULUS_RIFT_DK2
+	HMD_SONY_PSVR
+	HMD_VALVE_HTC_VIVE
+	KEY_A
+	KEY_B
+	KEY_BACK
+	KEY_BACKSPACE
+	KEY_C
+	KEY_D
+	KEY_DOWN
+	KEY_E
+	KEY_EIGHT
+	KEY_ENTER
+	KEY_ESCAPE
+	KEY_F
+	KEY_F1
+	KEY_F10
+	KEY_F11
+	KEY_F12
+	KEY_F2
+	KEY_F3
+	KEY_F4
+	KEY_F5
+	KEY_F6
+	KEY_F7
+	KEY_F8
+	KEY_F9
+	KEY_FIVE
+	KEY_FOUR
+	KEY_G
+	KEY_H
+	KEY_I
+	KEY_J
+	KEY_K
+	KEY_L
+	KEY_LEFT
+	KEY_LEFT_ALT
+	KEY_LEFT_CONTROL
+	KEY_LEFT_SHIFT
+	KEY_M
+	KEY_MENU
+	KEY_N
+	KEY_NINE
+	KEY_O
+	KEY_ONE
+	KEY_P
+	KEY_Q
+	KEY_R
+	KEY_RIGHT
+	KEY_RIGHT_ALT
+	KEY_RIGHT_CONTROL
+	KEY_RIGHT_SHIFT
+	KEY_S
+	KEY_SEVEN
+	KEY_SIX
+	KEY_SPACE
+	KEY_T
+	KEY_THREE
+	KEY_TWO
+	KEY_U
+	KEY_UP
+	KEY_V
+	KEY_VOLUME_DOWN
+	KEY_VOLUME_UP
+	KEY_W
+	KEY_X
+	KEY_Y
+	KEY_Z
+	KEY_ZERO
+	LOC_COLOR_AMBIENT
+	LOC_COLOR_DIFFUSE
+	LOC_COLOR_SPECULAR
+	LOC_MAP_ALBEDO
+	LOC_MAP_BRDF
+	LOC_MAP_CUBEMAP
+	LOC_MAP_DIFFUSE
+	LOC_MAP_EMISSION
+	LOC_MAP_HEIGHT
+	LOC_MAP_IRRADIANCE
+	LOC_MAP_METALNESS
+	LOC_MAP_NORMAL
+	LOC_MAP_OCCUSION
+	LOC_MAP_PREFILTER
+	LOC_MAP_ROUGHNESS
+	LOC_MAP_SPECULAR
+	LOC_MATRIX_MODEL
+	LOC_MATRIX_MVP
+	LOC_MATRIX_PROJECTION
+	LOC_MATRIX_VIEW
+	LOC_VECTOR_VIEW
+	LOC_VERTEX_COLOR
+	LOC_VERTEX_NORMAL
+	LOC_VERTEX_POSITION
+	LOC_VERTEX_TANGENT
+	LOC_VERTEX_TEXCOORD01
+	LOC_VERTEX_TEXCOORD02
+	LOG_DEBUG
+	LOG_ERROR
+	LOG_INFO
+	LOG_OTHER
+	LOG_WARNING
+	MAP_ALBEDO
+	MAP_BRDF
+	MAP_CUBEMAP
+	MAP_DIFFUSE
+	MAP_EMISSION
+	MAP_HEIGHT
+	MAP_IRRADIANCE
+	MAP_METALNESS
+	MAP_NORMAL
+	MAP_OCCLUSION
+	MAP_PREFILTER
+	MAP_ROUGHNESS
+	MAP_SPECULAR
+	MAX_MATERIAL_MAPS
+	MAX_SHADER_LOCATIONS
+	MAX_TOUCH_POINTS
+	MOUSE_LEFT_BUTTON
+	MOUSE_MIDDLE_BUTTON
+	MOUSE_RIGHT_BUTTON
+	RAD2DEG
+	UNCOMPRESSED_GRAYSCALE
+	UNCOMPRESSED_GRAY_ALPHA
+	UNCOMPRESSED_R32
+	UNCOMPRESSED_R32G32B32
+	UNCOMPRESSED_R32G32B32A32
+	UNCOMPRESSED_R4G4B4A4
+	UNCOMPRESSED_R5G5B5A1
+	UNCOMPRESSED_R5G6B5
+	UNCOMPRESSED_R8G8B8
+	UNCOMPRESSED_R8G8B8A8
+	WRAP_CLAMP
+	WRAP_MIRROR
+	WRAP_REPEAT
+	false
+	true
 );
 
 our $VERSION = '0.01';
@@ -819,14 +818,14 @@ sub AUTOLOAD {
     my ($error, $val) = constant($constname);
     if ($error) { croak $error; }
     {
-    no strict 'refs';
-    # Fixed between 5.005_53 and 5.005_61
-#XXX    if ($] >= 5.00561) {
-#XXX        *$AUTOLOAD = sub () { $val };
-#XXX    }
-#XXX    else {
-        *$AUTOLOAD = sub { $val };
-#XXX    }
+	no strict 'refs';
+	# Fixed between 5.005_53 and 5.005_61
+#XXX	if ($] >= 5.00561) {
+#XXX	    *$AUTOLOAD = sub () { $val };
+#XXX	}
+#XXX	else {
+	    *$AUTOLOAD = sub { $val };
+#XXX	}
     }
     goto &$AUTOLOAD;
 }
@@ -856,9 +855,6 @@ See L<Graphics::Raylib> for a Perlish wrapper. This XS wrapper wraps version 1.9
 
 =head2 EXPORT
 
-None by default.
-
-=head2 EXPORT
 
 None by default.
 
@@ -1076,17 +1072,11 @@ None by default.
   MOUSE_MIDDLE_BUTTON
   MOUSE_RIGHT_BUTTON
   RAD2DEG
-  RRES_TYPE_DIRECTORY
-  RRES_TYPE_FONT_CHARDATA
-  RRES_TYPE_FONT_IMAGE
-  RRES_TYPE_IMAGE
-  RRES_TYPE_RAW
-  RRES_TYPE_TEXT
-  RRES_TYPE_VERTEX
-  RRES_TYPE_WAVE
   UNCOMPRESSED_GRAYSCALE
   UNCOMPRESSED_GRAY_ALPHA
+  UNCOMPRESSED_R32
   UNCOMPRESSED_R32G32B32
+  UNCOMPRESSED_R32G32B32A32
   UNCOMPRESSED_R4G4B4A4
   UNCOMPRESSED_R5G5B5A1
   UNCOMPRESSED_R5G6B5
@@ -1173,7 +1163,6 @@ None by default.
   void DrawRectangleLines(int posX, int posY, int width, int height, Color color)
   void DrawRectanglePro(Rectangle rec, Vector2 origin, float rotation, Color color)
   void DrawRectangleRec(Rectangle rec, Color color)
-  void DrawRectangleT(int posX, int posY, int width, int height, Color color)
   void DrawRectangleV(Vector2 position, Vector2 size, Color color)
   void DrawSphere(Vector3 centerPos, float radius, Color color)
   void DrawSphereEx(Vector3 centerPos, float radius, int rings, int slices, Color color)
@@ -1205,7 +1194,7 @@ None by default.
   Image GenImageGradientH(int width, int height, Color left, Color right)
   Image GenImageGradientRadial(int width, int height, float density, Color inner, Color outer)
   Image GenImageGradientV(int width, int height, Color top, Color bottom)
-  Image GenImagePerlinNoise(int width, int height, float scale)
+  Image GenImagePerlinNoise(int width, int height, int offsetX, int offsetY, float scale)
   Image GenImageWhiteNoise(int width, int height, float factor)
   Mesh GenMeshCube(float width, float height, float length)
   Mesh GenMeshCubicmap(Image cubicmap, Vector3 cubeSize)
@@ -1231,6 +1220,7 @@ None by default.
   const char *GetDirectoryPath(const char *fileName)
   const char *GetExtension(const char *fileName)
   int GetFPS(void)
+  const char *GetFileName(const char *filePath)
   float GetFrameTime(void)
   int GetGamepadAxisCount(int gamepad)
   float GetGamepadAxisMovement(int gamepad, int axis)
@@ -1245,6 +1235,7 @@ None by default.
   int GetHexValue(Color color)
   Color *GetImageData(Image image)
   int GetKeyPressed(void)
+  Matrix GetMatrixModelview()
   Vector2 GetMousePosition(void)
   Ray GetMouseRay(Vector2 mousePosition, Camera camera)
   int GetMouseWheelMove(void)
@@ -1252,6 +1243,7 @@ None by default.
   int GetMouseY(void)
   float GetMusicTimeLength(Music music)
   float GetMusicTimePlayed(Music music)
+  int GetPixelDataSize(int width, int height, int format)
   int GetRandomValue(int min, int max)
   int GetScreenHeight(void)
   int GetScreenWidth(void)
@@ -1259,6 +1251,7 @@ None by default.
   int GetShaderLocation(Shader shader, const char *uniformName)
   Image GetTextureData(Texture2D texture)
   Texture2D GetTextureDefault(void)
+  double GetTime(void)
   int GetTouchPointsCount(void)
   Vector2 GetTouchPosition(int index)
   int GetTouchX(void)
@@ -1268,7 +1261,10 @@ None by default.
   const char *GetWorkingDirectory(void)
   Vector2 GetWorldToScreen(Vector3 position, Camera camera)
   void HideCursor(void)
+  void ImageAlphaClear(Image *image, Color color, float threshold)
+  void ImageAlphaCrop(Image *image, float threshold)
   void ImageAlphaMask(Image *image, Image alphaMask)
+  void ImageAlphaPremultiply(Image *image)
   void ImageColorBrightness(Image *image, int brightness)
   void ImageColorContrast(Image *image, float contrast)
   void ImageColorGrayscale(Image *image)
@@ -1284,6 +1280,7 @@ None by default.
   void ImageFlipHorizontal(Image *image)
   void ImageFlipVertical(Image *image)
   void ImageFormat(Image *image, int newFormat)
+  void ImageMipmaps(Image *image)
   void ImageResize(Image *image, int newWidth, int newHeight)
   void ImageResizeNN(Image *image,int newWidth,int newHeight)
   Image ImageText(const char *text, int fontSize, Color color)
@@ -1296,6 +1293,7 @@ None by default.
   void InitWindow(int width, int height, const char *data)
   bool IsAudioBufferProcessed(AudioStream stream)
   bool IsAudioDeviceReady(void)
+  bool IsAudioStreamPlaying(AudioStream stream)
   bool IsCursorHidden(void)
   bool IsFileDropped(void)
   bool IsFileExtension(const char *fileName, const char *ext)
@@ -1357,6 +1355,8 @@ None by default.
   void ResumeMusicStream(Music music)
   void ResumeSound(Sound sound)
   void SaveImageAs(const char *fileName, Image image)
+  void SetAudioStreamPitch(AudioStream stream, float pitch)
+  void SetAudioStreamVolume(AudioStream stream, float volume)
   void SetCameraAltControl(int altKey)
   void SetCameraMode(Camera camera, int mode)
   void SetCameraMoveControls(int frontKey, int backKey,
@@ -1364,14 +1364,14 @@ None by default.
                                  int upKey, int downKey)
   void SetCameraPanControl(int panKey)
   void SetCameraSmoothZoomControl(int szKey)
-  void SetConfigFlags(char flags)
+  void SetConfigFlags(unsigned char flags)
   void SetExitKey(int key)
   void SetGesturesEnabled(unsigned int gestureFlags)
   void SetMasterVolume(float volume)
   void SetMatrixModelview(Matrix view)
   void SetMatrixProjection(Matrix proj)
   void SetMousePosition(Vector2 position)
-  void SetMusicLoopCount(Music music, float count)
+  void SetMusicLoopCount(Music music, int count)
   void SetMusicPitch(Music music, float pitch)
   void SetMusicVolume(Music music, float volume)
   void SetShaderValue(Shader shader, int uniformLoc, const float *value, int size)
@@ -1382,6 +1382,7 @@ None by default.
   void SetTargetFPS(int fps)
   void SetTextureFilter(Texture2D texture, int filterMode)
   void SetTextureWrap(Texture2D texture, int wrapMode)
+  void SetTraceLog(unsigned char types)
   void SetVrDistortionShader(Shader shader)
   void SetWindowIcon(Image image)
   void SetWindowMinSize(int width, int height)
@@ -1427,6 +1428,8 @@ None by default.
   bool WindowShouldClose(void)
 
 
+
+
 =head1 SEE ALSO
 
 L<http://www.raylib.com>
